@@ -21,7 +21,7 @@ import random
 import socket
 import sys
 import time
-from test.utils import get_pool, joinall
+from test.utils import flaky, get_pool, joinall
 
 from bson.codec_options import DEFAULT_CODEC_OPTIONS
 from bson.son import SON
