@@ -25,7 +25,7 @@ import warnings
 sys.path[0:0] = [""]
 
 from test import unittest
-from test.helpers import clear_warning_registry
+from test.helpers_shared import clear_warning_registry
 
 from pymongo.common import INTERNAL_URI_OPTION_NAME_MAP, _CaseInsensitiveDictionary, validate
 from pymongo.compression_support import _have_snappy
